数据清洗问题
这里，我们还是拿预测股价走势当例子。对于机器学习模型来说，我们希望发现的是一些比较稳定的数据模式和规律，这就要求我们剔除一些存在异常的数据。比如，把刚上市的新股剔除掉，因为它们的表现往往具有独特性；把刚开市时前几分钟以及闭市前最后几分钟的数据点剔除掉，因为这个时段的数据噪音也比较大；把一些垃圾股，以及近期受政策影响较大的股票剔除掉，因为这些数据也不具备一般性。依此类推，当我们清洗掉大部分异常数据之后，在留下的数据中，更有可能发掘到稳定的、预测准确度高的规律。
